@@ -75,8 +75,11 @@ class StopwatchApp(hildon.Program):
         self.clear_time()
         
         # load beep
-        mixer.init()
-        self.sound = mixer.Sound("/usr/share/sounds/ui-default_beep.wav")
+        try:
+            mixer.init()
+            self.sound = mixer.Sound("/usr/share/sounds/ui-default_beep.wav")
+        except:
+            self.sound = None
         
         self.drawUI()
         menu = self.create_menu(None)
@@ -258,8 +261,8 @@ class StopwatchApp(hildon.Program):
             return
         
         if now >= self.stopTime:
-#            self.player.set_state(gst.STATE_PLAYING)
-            self.sound.play()
+            if self.sound:
+                self.sound.play()
             self.running = False
             hildon.hildon_banner_show_information(self.window, "", "Timer finished at %s" % str(now)[:-7])
             self.stopButton.set_sensitive(False)
